.. _install:

Installation
============

For Python versions prior to 3.11 also install ``izulu[compatibility]``.

::

    # py311 and higher
    pip install izulu

    # py38-py310
    pip install izulu izulu[compatibility]
